@@ -1619,23 +1619,23 @@ class LibraryModel:
             "description": "The MAS-seq 10 array element model.",
             "version": "2.0.1",
             "array_element_structure": (
-                ("Q", "VENUS", "CBC", "UMI", "BOREAS", "cDNA", "Poly_A", "MARS"),
-                ("C", "VENUS", "CBC", "UMI", "BOREAS", "cDNA", "Poly_A", "MARS"),
-                ("M", "VENUS", "CBC", "UMI", "BOREAS", "cDNA", "Poly_A", "MARS"),
-                ("I", "VENUS", "CBC", "UMI", "BOREAS", "cDNA", "Poly_A", "MARS"),
-                ("O", "VENUS", "CBC", "UMI", "BOREAS", "cDNA", "Poly_A", "MARS"),
-                ("J", "VENUS", "CBC", "UMI", "BOREAS", "cDNA", "Poly_A", "MARS"),
-                ("B", "VENUS", "CBC", "UMI", "BOREAS", "cDNA", "Poly_A", "MARS"),
-                ("D", "VENUS", "CBC", "UMI", "BOREAS", "cDNA", "Poly_A", "MARS"),
-                ("K", "VENUS", "CBC", "UMI", "BOREAS", "cDNA", "Poly_A", "MARS"),
+                ("Q", "5p_Adapter", "CBC", "UMI", "SLS", "cDNA", "Poly_A", "3p_Adapter"),
+                ("C", "5p_Adapter", "CBC", "UMI", "SLS", "cDNA", "Poly_A", "3p_Adapter"),
+                ("M", "5p_Adapter", "CBC", "UMI", "SLS", "cDNA", "Poly_A", "3p_Adapter"),
+                ("I", "5p_Adapter", "CBC", "UMI", "SLS", "cDNA", "Poly_A", "3p_Adapter"),
+                ("O", "5p_Adapter", "CBC", "UMI", "SLS", "cDNA", "Poly_A", "3p_Adapter"),
+                ("J", "5p_Adapter", "CBC", "UMI", "SLS", "cDNA", "Poly_A", "3p_Adapter"),
+                ("B", "5p_Adapter", "CBC", "UMI", "SLS", "cDNA", "Poly_A", "3p_Adapter"),
+                ("D", "5p_Adapter", "CBC", "UMI", "SLS", "cDNA", "Poly_A", "3p_Adapter"),
+                ("K", "5p_Adapter", "CBC", "UMI", "SLS", "cDNA", "Poly_A", "3p_Adapter"),
                 # The last element may not currently have the "R" adapter in this version of the library:
-                ("H", "VENUS", "CBC", "UMI", "BOREAS", "cDNA", "Poly_A", "MARS", "R"),
+                ("H", "5p_Adapter", "CBC", "UMI", "SLS", "cDNA", "Poly_A", "3p_Adapter", "R"),
             ),
             "adapters": {
-                "VENUS": "TCTACACGACGCTCTTCCGATCT",
+                "5p_Adapter": "TCTACACGACGCTCTTCCGATCT",
                 "Poly_A": {HPR_SEGMENT_TYPE_NAME: ("A", 30)},
-                "MARS": "GTACTCTGCGTTGATACCACTGCTT",
-                "BOREAS": "TTTCTTATATGGG",
+                "3p_Adapter": "GTACTCTGCGTTGATACCACTGCTT",
+                "SLS": "TTTCTTATATGGG",
                 "B": "ACTTGTAAGCTGTCTA",
                 "C": "ACTCTGTCAGGTCCGA",
                 "D": "ACCTCCTCCTCCAGAA",
@@ -1652,8 +1652,8 @@ class LibraryModel:
                 "cDNA": RANDOM_SEGMENT_NAME,
             },
             "direct_connections": {
-                "Poly_A": {"MARS"},
-                "MARS": {
+                "Poly_A": {"3p_Adapter"},
+                "3p_Adapter": {
                     "Q",
                     "C",
                     "M",
@@ -1666,24 +1666,24 @@ class LibraryModel:
                     "H",
                     "R",
                 },
-                "B": {"VENUS"},
-                "C": {"VENUS"},
-                "D": {"VENUS"},
-                "H": {"VENUS"},
-                "I": {"VENUS"},
-                "J": {"VENUS"},
-                "K": {"VENUS"},
-                "M": {"VENUS"},
-                "O": {"VENUS"},
-                "Q": {"VENUS"},
-                "R": {"VENUS"},
-                "VENUS": {"CBC"},
+                "B": {"5p_Adapter"},
+                "C": {"5p_Adapter"},
+                "D": {"5p_Adapter"},
+                "H": {"5p_Adapter"},
+                "I": {"5p_Adapter"},
+                "J": {"5p_Adapter"},
+                "K": {"5p_Adapter"},
+                "M": {"5p_Adapter"},
+                "O": {"5p_Adapter"},
+                "Q": {"5p_Adapter"},
+                "R": {"5p_Adapter"},
+                "5p_Adapter": {"CBC"},
                 "CBC": {"UMI"},
-                "UMI": {"BOREAS"},
-                "BOREAS": {"cDNA"},
+                "UMI": {"SLS"},
+                "SLS": {"cDNA"},
                 "cDNA": {"Poly_A"},
             },
-            "start_element_names": {"Q", "VENUS"},
+            "start_element_names": {"Q", "5p_Adapter"},
             "end_element_names": {"Poly_A", "R"},
             "named_random_segments": {"UMI", "cDNA", "CBC"},
             "coding_region": "cDNA",
